@@ -2,6 +2,7 @@
   This file is part of Lokalize
 
   Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -42,7 +43,8 @@ public:
 
     /**
      * @param term is the term matched
-     * @param entry is a whole entry
+     * @param entryId is a whole entry
+     * @param capFirst whether the first letter should be capitalized
      */
     void setText(const QString& term, const QByteArray& entryId, bool capFirst);
     void mousePressEvent(QMouseEvent* /* event*/) override;
@@ -59,10 +61,5 @@ private:
     QAction* m_action; //used only for shortcut purposes
 };
 
-
-
-
-
-
 }
 #endif
